
# Overview

Particula is a Python-based aerosol particle simulator. Its goal is to provide a robust aerosol simulation (including both gas and particle phases) that can be used to answer scientific questions arising from experiments and research endeavors.

The Particula website [https://uncscode.github.io/particula](https://uncscode.github.io/particula) contains the API reference, how-to guides, and tutorials.

## PyPI Installation

If your Python environment is already set up, you can install [`particula` via pip](https://pypi.org/project/particula/) using the following command:

``` bash
pip install particula
```
